import { parse, stringify } from '@iarna/toml';
import { fs, path } from '@vuepress/utils';
const configName = 'netlify.toml';
const readConfig = (filepath) => {
    let netlifyConfig = '';
    if (fs.existsSync(filepath)) {
        netlifyConfig = fs.readFileSync(filepath, 'utf-8') || '';
    }
    return parse(netlifyConfig) || {};
};
const writeConfig = (filepath, netlifyConfig) => {
    fs.writeFileSync(filepath, stringify(netlifyConfig), 'utf-8');
};
const resolveFunctions = (config, { directory }, app) => {
    const functions = (config.functions = config.functions || {});
    functions.directory =
        functions.directory || path.relative(app.dir.dest('../'), directory.dest);
};
const resolveRedirects = (config, { proxyPrefix }) => {
    const funcDir = '/' + (config.functions.directory || '').replace(/^\//, '');
    const redirects = (config.redirects = config.redirects || []);
    if (!redirects.some((redirect) => redirect?.to?.startsWith(funcDir))) {
        redirects.push({
            from: path.join('/', proxyPrefix, '*'),
            to: path.join(funcDir, ':splat'),
            status: 200,
            force: true,
            Headers: {
                'X-From': 'Netlify',
            },
        });
    }
};
export const generateNetlifyConfig = (app, options) => {
    const configPath = path.join(process.cwd(), configName);
    const config = readConfig(configPath);
    resolveFunctions(config, options, app);
    resolveRedirects(config, options);
    writeConfig(configPath, config);
    return config;
};
